Background enum

Background color presets

Inheritance
Available extensions

Values

transparent → const Background
background → const Background
backgroundSecondary → const Background
backgroundTertiary → const Background
surface → const Background
surfaceVariant → const Background
card → const Background
cardHover → const Background
cardAlt → const Background
input → const Background
primary → const Background
secondary → const Background
tertiary → const Background
accent → const Background
accentContainer → const Background
success → const Background
successContainer → const Background
warning → const Background
error → const Background
info → const Background
overlay → const Background
tooltip → const Background
code → const Background
white → const Background
black → const Background
muted → const Background
brandPrimary → const Background
brandSecondary → const Background
destructive → const Background

Properties

css String
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Background>
A constant List of the values in this enum, in order of their declaration.