ElementNode class

A node that represents an element with a tag, attributes and children.

Inheritance
Available extensions

Constructors

ElementNode(String tag, Map<String, String> attributes, List<Node>? children)
const

Properties

attributes Map<String, String>
final
children List<Node>?
final
hashCode int
The hash code for this object.
no setterinherited
innerText String

Available on Node, provided by the NodeExtension extension

Recursively gets the inner text of the node.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited