KBResourceGridComponent class

Inheritance

Constructors

KBResourceGridComponent()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pattern Pattern
The name pattern that the component matches.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme → ThemeExtension<Object?>?
An optional theme extension for this component.
no setterinherited

Methods

apply(String name, Map<String, String> attributes, Widget? child) Widget
Builds a component with the given name, attributes, and child.
override
create(Node node, NodesBuilder builder) Component?
Creates a component for the given node, or returns null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited