RouteLoaderBase<T extends PageSource> class abstract

A base class for RouteLoader implementations.

Implemented types
Available extensions

Constructors

RouteLoaderBase({bool debugPrint = false})

Properties

debugPrint bool
final
hashCode int
The hash code for this object.
no setterinherited
resolver ConfigResolver
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources List<T>
no setter

Methods

addSource(T source) → void
getSourceForPage(Page page) → T?
invalidateAll() → void
invalidatePage(Page page) → void
Invalidates the given page.
override
invalidateRoutes() → void
invalidateSource(T source, {bool rebuild = true}) → void
loadPageSources() Future<List<T>>
loadRoutes(ConfigResolver resolver, bool eager) Future<List<RouteBase>>
Loads the routes with the given ConfigResolver.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReassemble() → void
readPartial(String path, Page page) Future<String>
Reads a partial from the given path.
override
readPartialSync(String path, Page page) String
Reads a partial from the given path synchronously.
override
removeSource(T source) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited