BlogLayout class
A layout for blog articles.
This layout includes a header and title block.
It supports light and dark mode and custom theme colors.
- Inheritance
-
- Object
- PageLayoutBase
- BlogLayout
Constructors
- BlogLayout({Component? header, FontFamily textFont = _defaultTextFont})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Component?
-
The header component to render, usually a
Header.final - name → String
-
The name pattern that the layout matches.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textFont → FontFamily
-
The font to use for the text content, excluding heading.
final
Methods
-
buildBody(
Page page, Component child) → Component -
override
-
buildHead(
Page page) → Iterable< Component> -
override
-
buildLayout(
Page page, Component child) → Component -
Builds the layout for the given page and child component.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited