FilesystemDataLoader class
A data loader that loads data from the filesystem.
- Implemented types
Constructors
- FilesystemDataLoader(String directory, {@visibleForTesting FileSystem fileSystem = const LocalFileSystem(), @visibleForTesting DirectoryWatcherFactory? watcherFactory})
-
factory
Properties
- directory → String
-
final
- fileSystem → FileSystem
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- watcherFactory → DirectoryWatcherFactory
-
final
Methods
-
loadData(
Page page) → Future< void> -
Loads the data for the given
page.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
reset(
) → void