SearchIndexGenerator class
Generates a search index JSON file from the navigation manifest.
The search index is a flat list of all pages with their metadata, optimized for client-side searching.
Constructors
- SearchIndexGenerator({required SiteConfig config, required NavManifest manifest})
-
const
Properties
- config → SiteConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manifest → NavManifest
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
{bool pretty = false}) → String - Generate the search index as a JSON string.
-
generateEntries(
) → List< SearchIndexEntry> - Generate the search index as a list of entries.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited