TextColor enum
Text/foreground color presets
Values
- primary → const TextColor
- secondary → const TextColor
- muted → const TextColor
- mutedForeground → const TextColor
- subtle → const TextColor
- faint → const TextColor
- accent → const TextColor
- accentForeground → const TextColor
- success → const TextColor
- successForeground → const TextColor
- warning → const TextColor
- warningForeground → const TextColor
- error → const TextColor
- errorForeground → const TextColor
- info → const TextColor
- infoForeground → const TextColor
- onPrimary → const TextColor
- onSecondary → const TextColor
- onBackground → const TextColor
- onSurface → const TextColor
- onSurfaceVariant → const TextColor
- cardForeground → const TextColor
- inputForeground → const TextColor
- tooltipForeground → const TextColor
- white → const TextColor
- black → const TextColor
- inherit → const TextColor
- brandPrimary → const TextColor
- brand → const TextColor
- brandSecondary → const TextColor
- star → const TextColor
Properties
- css → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited